
# Slot: is excipient of


holds between a chemical substance and a drug in which the former is a part of the latter, and is a biologically inactive component

URI: [biolink:is_excipient_of](https://w3id.org/biolink/vocab/is_excipient_of)


## Domain and Range

[ChemicalSubstance](ChemicalSubstance.md) &#8594;  <sub>0..\*</sub> [Drug](Drug.md)

## Parents

 *  is_a: [part of](part_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | WIKIDATA:Q902638 |
| **In Subsets:** | | translator_minimal |

